@@ -17,20 +17,24 @@ class FileTransferProgressHandler:
 
     Parameters
     ----------
-    chunk_size : int
+    chunk_size : int or None
         The constant interval between size thresholds.
     total_size : int
         The total size of a file in bytes.
     callback : callable
         The callback to be invoked when a size threshold has been crossed.
     """
+    MINIMUM_CHUNK_SIZE = 1
 
     def __init__(self, chunk_size, total_size, callback):
-        if not isinstance(chunk_size, int) or chunk_size <= 0:
-            raise ValueError("chunk_size must be a positive integer")
+        if not isinstance(chunk_size, int) or chunk_size < 0:
+            raise ValueError("chunk_size must be a non-negative integer")
 
-        if not isinstance(total_size, int) or total_size <= 0:
-            raise ValueError("total_size must be a positive integer")
+        if chunk_size < self.MINIMUM_CHUNK_SIZE:
+            chunk_size = self.MINIMUM_CHUNK_SIZE
+
+        if not isinstance(total_size, int) or total_size < 0:
+            raise ValueError("total_size must be a non-negative integer")
 
         if not callable(callback):
             raise ValueError("callback must be callable")
@@ -174,8 +178,7 @@ class FilesAPI(GenericAPI):
         url = f"{self._files_base_url}workspace/{space_id}/"
         params = {
             'path': path,
-            # Convert to 1-based indexing used by database method.
-            'start': start + 1,
+            'start': start,
             'pageLength': length,
         }
 
@@ -234,7 +237,7 @@ class FilesAPI(GenericAPI):
         url = f"{self._files_base_url}workspace/{space_id}/"
         params = {
             'path': path,
-            'start': 1,
+            'start': 0,
             'pageLength': 25,
         }
 
